==> haskell-x509-1.7.5-133-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509
version:              1.7.5
visibility:           public
id:                   x509-1.7.5-DEBNMxVc4B9DIpqD5BhH0E
key:                  x509-1.7.5-DEBNMxVc4B9DIpqD5BhH0E
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  c3485063db4055c7bf2665382a4e3360
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-8.10.4/site-local/x509-1.7.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/x509-1.7.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/x509-1.7.5
hs-libraries:         HSx509-1.7.5-DEBNMxVc4B9DIpqD5BhH0E
depends:
    asn1-encoding-0.9.6-EbAeLRQPgth427v6xCJWgi
    asn1-parse-0.9.5-DYOehsB14QTGbqBehKkrKy
    asn1-types-0.3.4-FN5dJUUK5sM5hLeGc0C5om base-4.14.1.0
    bytestring-0.10.12.0 containers-0.6.2.1
    cryptonite-0.28-6tE3qLRdRA173sMttb2hCZ
    hourglass-0.2.12-3sMVAqDnBvqLgC2WhIR7CT
    memory-0.15.0-E8yvrlcxsw5JtBytoHmuPe mtl-2.2.2
    pem-0.2.4-KfhaIpUaN3eAITw6gwgWZb

haddock-interfaces:   /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html:         /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-1.7.5-134-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509
version:              1.7.5
visibility:           public
id:                   x509-1.7.5-5qqTct5MhqLKMl6AENMgzA
key:                  x509-1.7.5-5qqTct5MhqLKMl6AENMgzA
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  ee37ae737f77d13ce54bbc3ec97025ca
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-8.10.4/site-local/x509-1.7.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/x509-1.7.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/x509-1.7.5
hs-libraries:         HSx509-1.7.5-5qqTct5MhqLKMl6AENMgzA
depends:
    asn1-encoding-0.9.6-5heIzAN3kUz9qHhNuX5FWP
    asn1-parse-0.9.5-9oTNDOtYUeABda4JD5BQjq
    asn1-types-0.3.4-4mLdhHohRCs9bi91NR6KPx base-4.14.1.0
    bytestring-0.10.12.0 containers-0.6.2.1
    cryptonite-0.28-H6kcS5sVLxX1I4jG4jMnWM
    hourglass-0.2.12-EXFtIuM5N0z1sujoYpifBW
    memory-0.15.0-E8yvrlcxsw5JtBytoHmuPe mtl-2.2.2
    pem-0.2.4-1b6LyNbup3i6FmDF1IyU1l

haddock-interfaces:   /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html:         /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
